==> ev_framework-3.0.2.tar.gz: lib/_FrameWork/Ev/_Form_DropDown.dart <==
import 'dart:ui';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';

import '../vForm.dart';
import '../vText.dart';

class $$Form_DropDown extends StatefulWidget {
  vForm form;
  var skey;
  var id;
  TextEditingController controller;
  var label_text;
  Map map_data;
  var onchange;

  $$Form_DropDown(Key key,this.skey,this.form,this.id,this.controller,
      {this.label_text,this.map_data,this.onchange}):super(key:key);

  @override
  _FormDropDown_textState createState() => _FormDropDown_textState();
}

class _FormDropDown_textState extends State<$$Form_DropDown> {
  var id;
  var items;
  vForm form;

  @override
  void initState() {
    // TODO: implement initState
    id = widget.id;
    form = widget.form;
    items = widget.map_data
        .map((ID, value) {
      return MapEntry(
          ID,
          DropdownMenuItem<String>(
            value: ID,
            child: vText(value).size(form.$$_Input_Size).c(form.$$_Input_Color),
          ));
    }).values.toList();

    super.initState();
  }

  @override
  Widget build(BuildContext context) {

    Widget child = Container(
      height: form.$$_Input_Size + 14,
      child: Stack(
        children: [
          Positioned(
            top: -7,
            right: 0,
            left: (form.$$_Text_Align == TextAlign.right) ? null : 0,
            child: DropdownButtonHideUnderline(
             child: Theme(
               data: ThemeData(
                   canvasColor: form.$$_Dropdown_BG_Colors,
                ),
               child: DropdownButton(
                iconEnabledColor: form.$$_Input_Color,
                isExpanded: true,
                value: id,
                onChanged: (ID) {
                  setState(() {
                    id = ID;
                    widget.controller.text = ID;
                    if(widget.onchange != null)
                      {  widget.onchange(id); }
                  });
                },
                items: items,
            ),
             ),
           ),
         ),
        ],
      ));

    if(form.$$_Border_type ==0)
      { return Material(child:child,color: Colors.transparent,); }

    if (form.$$_Border_type == 1) {
      return Material(child:form_type1(child),color: Colors.transparent);
    }
    else {
      return Material(child:form_type2(child),color: Colors.transparent);
    }
  }

  Widget form_type1(Widget child) {
    var color = form.$$_item_error[widget.skey] == null
        ? form.$$_Border_Color
        : Colors.red;
    var error_text = form.$$_item_error[widget.skey] ?? "";


    return Container(
      padding: form.$$_Padding,
      child: Column(
        crossAxisAlignment: form.$$_Text_Align == TextAlign.right ? CrossAxisAlignment.end : CrossAxisAlignment.start,
        children: <Widget>[
          (form.$$_Lable_ratio > 0) ?
          Row(
              children: <Widget>[
                Expanded(flex: (form.$$_Lable_ratio * 100).round(), child: vText(widget.label_text).c(form.$$_Lable_Color).size(form.$$_Lable_Size)),
                SizedBox(width: 10),
                Expanded(flex: 100,child: Padding(
                  padding: const EdgeInsets.only(bottom:8.0),
                  child: child,
                ))
              ]):

          Row(
              children: <Widget>[
                Padding(
                  padding: const EdgeInsets.only(bottom: 8.0),
                  child: vText(widget.label_text).c(form.$$_Lable_Color).size(form.$$_Lable_Size),
                ),
                SizedBox(width: 10),
                Expanded(child: Padding(
                  padding: const EdgeInsets.only(bottom:8.0),
                  child: child,
                ))
              ]),

          Container(color: color, height: 1,),
          Text(error_text, style: TextStyle(color: Colors.red, fontSize: 12),
            textAlign: TextAlign.right,),
        ],
      ),
    );
  }


  Widget form_type2(Widget child) {
    var error_text = form.$$_item_error[widget.skey] ?? "";
    var decoration = BoxDecoration(
      border: Border.all(
        color: form.$$_item_error[widget.skey] == null
            ? form.$$_Border_Color
            : Colors.red,
        width: form.$$_Border_Width,
      ),
      borderRadius: BorderRadius.all(Radius.circular(form.$$_Round)),
    );

    return Container(
      padding: form.$$_Margin,
      child: Column(
        children: <Widget>[
          Row(
              crossAxisAlignment: CrossAxisAlignment.center,
              children: <Widget>[
                widget.label_text == "" ? Container() :

                Expanded(
                  flex: (form.$$_Lable_ratio >0) ? (form.$$_Lable_ratio * 100).round() : 0,
                  child: Row(children: [
                    Padding(
                      padding: const EdgeInsets.only(bottom:8.0),
                      child: vText(widget.label_text).c(form.$$_Lable_Color).size(form.$$_Lable_Size),
                    ),
                    SizedBox(width: 10),
                    ],),
                ),

                Expanded( flex: (form.$$_Lable_ratio >0) ? 100 : 1,
                  child:
                    Column(
                   crossAxisAlignment: form.$$_Text_Align == TextAlign.right ? CrossAxisAlignment.end : CrossAxisAlignment.start,
                   children: [
                    Container(padding: form.$$_Padding, child: Padding(
                      padding: const EdgeInsets.only(left: 10),
                      child: child,
                    ),
                      decoration: decoration,

                    ),
                    Padding(
                      padding: EdgeInsets.symmetric(horizontal: form.$$_Round + 5),
                      child: Text(error_text, style: TextStyle(color: Colors.red, fontSize: 12),),
                    ),
                  ],
                 ),

                )
              ]),


        ],
      ),
    );
  }
}

==> ev_framework-3.0.4.tar.gz: lib/_FrameWork/Ev/_Form_DropDown.dart <==
import 'dart:ui';
import 'package:ev_framework/_FrameWork/vText.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import '../vForm.dart';

class $$Form_DropDown extends StatefulWidget {
  vForm form;
  var skey;
  var id;
  TextEditingController controller;
  var label_text;
  Map map_data;
  var onchange;
  double width;

  $$Form_DropDown(Key key,this.skey,this.form,this.id,this.controller,this.width,
      {this.label_text,this.map_data,this.onchange}):super(key:key);

  @override
  _FormDropDown_textState createState() => _FormDropDown_textState();
}

class _FormDropDown_textState extends State<$$Form_DropDown> {
  var id;
  var items;
  vForm form;

  @override
  void initState() {
    // TODO: implement initState
    id = widget.id;
    form = widget.form;
    items = widget.map_data
        .map((ID, value) {
      return MapEntry(
          ID,
          DropdownMenuItem<String>(
            value: ID,
            child: vText(value).size(form.$$_Input_Size).c(form.$$_Input_Color),
          ));
    }).values.toList();

    super.initState();
  }

  @override
  Widget build(BuildContext context) {

    Widget child = Container(
        height: form.$$_Input_Size + 14,
        width: widget.width,
        child: Stack(
          children: [
            Positioned(
              top: -7,
              right: 0,
              left: (form.$$_Text_Align == TextAlign.right) ? null : 0,
              child: DropdownButtonHideUnderline(
                child: Theme(
                  data: ThemeData(
                    canvasColor: form.$$_Dropdown_BG_Colors,
                  ),
                  child: DropdownButton(
                    iconEnabledColor: form.$$_Input_Color,
                    //isExpanded: true,
                    value: id,
                    onChanged: (ID) {
                      setState(() {
                        id = ID;
                        widget.controller.text = ID;
                        if(widget.onchange != null)
                        {  widget.onchange(id); }
                      });
                    },
                    items: items,
                  ),
                ),
              ),
            ),
          ],
        ));

    if(form.$$_Border_type ==0)
    { return Material(child:child,color: Colors.transparent,); }

    if (form.$$_Border_type == 1) {
      return Material(child:form_type1(child),color: Colors.transparent);
    }
    else {
      return Material(child:form_type2(child),color: Colors.transparent);
    }
  }

  Widget form_type1(Widget child) {
    var color = form.$$_item_error[widget.skey] == null
        ? form.$$_Border_Color
        : Colors.red;
    var error_text = form.$$_item_error[widget.skey] ?? "";


    return Container(
      padding: form.$$_Margin,
      child: Column(
        crossAxisAlignment: form.$$_Text_Align == TextAlign.right ? CrossAxisAlignment.end : CrossAxisAlignment.start,
        children: <Widget>[
          Padding(padding: form.$$_Padding,child:
          (form.$$_Lable_ratio > 0) ?
          Row(
              children: <Widget>[
                Expanded(flex: (form.$$_Lable_ratio * 100).round(), child: vText(widget.label_text).c(form.$$_Lable_Color).size(form.$$_Lable_Size)),
                SizedBox(width: 10),
                Expanded(flex: 100,child: Padding(
                  padding: const EdgeInsets.only(bottom:8.0),
                  child: child,
                ))
              ]):

          Row(
              children: <Widget>[
                vText(widget.label_text).c(form.$$_Lable_Color).size(form.$$_Lable_Size),
                SizedBox(width: 10),
                Expanded(child: Padding(
                  padding: const EdgeInsets.only(bottom:8.0),
                  child: child,
                ))
              ]),
          ),
          Container(color: color, height: 1,),
          Text(error_text, style: TextStyle(color: Colors.red, fontSize: 12),
            textAlign: TextAlign.right,),
        ],
      ),
    );
  }


  Widget form_type2(Widget child) {
    var error_text = form.$$_item_error[widget.skey] ?? "";
    var decoration = BoxDecoration(
      border: Border.all(
        color: form.$$_item_error[widget.skey] == null
            ? form.$$_Border_Color
            : Colors.red,
        width: form.$$_Border_Width,
      ),
      borderRadius: BorderRadius.all(Radius.circular(form.$$_Round)),
    );

    return Container(
      padding: form.$$_Margin,
      child: Column(
        children: <Widget>[
          Row(
              crossAxisAlignment: CrossAxisAlignment.center,
              children: <Widget>[
                widget.label_text == "" ? Container() :

                Expanded(
                  flex: (form.$$_Lable_ratio >0) ? (form.$$_Lable_ratio * 100).round() : 0,
                  child: Row(children: [
                    Padding(
                      padding: const EdgeInsets.only(bottom:8.0),
                      child: vText(widget.label_text).c(form.$$_Lable_Color).size(form.$$_Lable_Size),
                    ),
                    SizedBox(width: 10),
                  ],),
                ),

                Expanded( flex: (form.$$_Lable_ratio >0) ? 100 : 1,
                  child:
                  Column(
                    crossAxisAlignment: form.$$_Text_Align == TextAlign.right ? CrossAxisAlignment.end : CrossAxisAlignment.start,
                    children: [
                      Container(padding: form.$$_Padding, child: Padding(
                        padding: const EdgeInsets.only(left: 10),
                        child: child,
                      ),
                        decoration: decoration,

                      ),
                      Padding(
                        padding: EdgeInsets.symmetric(horizontal: form.$$_Round + 5),
                        child: Text(error_text, style: TextStyle(color: Colors.red, fontSize: 12),),
                      ),
                    ],
                  ),

                )
              ]),


        ],
      ),
    );
  }
}
